CREATE OR REPLACE PROCEDURE ANTECIPACAO_ICMS_ARROZ(
   P_NRSEQUMAPAPU    IN MAPAAPURAC.NRSEQUMAPAPU%TYPE)
AS
   V_NRSEQITMAPARECUP   NUMBER;
   V_BOANTECIP          BOOLEAN;
   CURSOR C_CODANTECIPARROZ (P_NRSEQUMAPAPU IN MAPAAPURAC.NRSEQUMAPAPU%TYPE) IS
      (SELECT CDFILIAL, NRLANCTONF, NRSEQITMAPR, DSITEMMAPR, CDITEMOCOR, DSITEMOCOR,
              DSFLEGALOCOR, CDAJUSTEITMAPA, CDAJUSTEITSEF, CDITPROCEDENCIA
         FROM ITMAPARECUP
        WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU
          AND IDTIPOITMAPR = 'OC'
          AND DSITEMMAPR   = 'ANTECIPAO ARROZ'
          AND NRLANCTONF||CDFILIAL IS NOT NULL);
   TYPE CODANTECIPARROZ IS TABLE OF C_CODANTECIPARROZ%ROWTYPE;
   V_CODANTECIPARROZ    CODANTECIPARROZ;
   V_IDESANTIARROZ      VARCHAR2(01);
   V_CDTPOPANTIARROZ    VARCHAR2(02);
   V_CDITEMOCOR         VARCHAR2(05);
   V_DSITEMOCOR         VARCHAR2(300);
   V_DSFLEGALOCOR       VARCHAR2(100);
   V_CDAJUSTEITMAPA     VARCHAR2(10);
   V_CDAJUSTEITSEF      VARCHAR2(03);
   V_CDITPROCEDENCIA    VARCHAR2(10);
   V_NRSEQITMAPR        VARCHAR2(10);
BEGIN
   /******** Busca as informaes referentes as NF's de Antecipao do ICMS que j ecistiam no Mapa,
             para salvar os dados digitados pelo usurio, em caso de reapurao de mapas ********/
   OPEN  C_CODANTECIPARROZ (P_NRSEQUMAPAPU);
   FETCH C_CODANTECIPARROZ BULK COLLECT INTO V_CODANTECIPARROZ;
   CLOSE C_CODANTECIPARROZ;

   /******** Busca o ltimo sequencial de Outros Crditos na ITMAPARECUP ********/
   BEGIN
      SELECT MAX(NRSEQITMAPR) AS NRSEQITMAPR
        INTO V_NRSEQITMAPARECUP
        FROM ITMAPARECUP
       WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU
         AND IDTIPOITMAPR = 'OC';
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_NRSEQITMAPARECUP := 0;
   END;

   V_NRSEQITMAPARECUP := NVL(V_NRSEQITMAPARECUP,0);

   /******** Deleta os itens de outros crditos referentes a Antecipao do ICMS do Arroz (Reapurao de Mapa) ********/
   DELETE FROM ITMAPARECUP
    WHERE NRSEQUMAPAPU = P_NRSEQUMAPAPU
      AND IDTIPOITMAPR = 'OC'
      AND DSITEMMAPR   = 'ANTECIPAO ARROZ'
      AND CDFILIAL||NRLANCTONF IS NOT NULL;

   /******** Busca a parametrizao do Tipo de Operao para gerar o crdito de Antecipao do ICMS ********/
   BEGIN
      SELECT IDESANTIARROZ, CDTPOPANTIARROZ
        INTO V_IDESANTIARROZ, V_CDTPOPANTIARROZ
        FROM PARAMFISCAL;
   EXCEPTION
      WHEN NO_DATA_FOUND THEN
         V_IDESANTIARROZ   := NULL;
         V_CDTPOPANTIARROZ := NULL;
   END;

   IF (V_IDESANTIARROZ IS NOT NULL) AND (V_CDTPOPANTIARROZ IS NOT NULL) THEN
      V_NRSEQITMAPR     := 0;
      /******** Busca as notas de antecipao no perodo ********/
      FOR C_ANTECIPARROZ IN (SELECT SUM(IP.VRCONTABILNF) AS VRCONTABILNF, IP.NRLANCTONF, IP.CDFILIAL
                               FROM NOTAFISCAL NF, IMPOSTONF IP
                              WHERE NF.CDFILIAL     = IP.CDFILIAL
                                AND NF.NRLANCTONF   = IP.NRLANCTONF
                                AND NF.CDTIPOOPER   = V_CDTPOPANTIARROZ
                                AND NF.IDENTRSAIDOP = V_IDESANTIARROZ
                                AND IP.NRSEQUMAPAPU = P_NRSEQUMAPAPU
                              GROUP BY IP.NRLANCTONF, IP.CDFILIAL) LOOP

         V_CDITEMOCOR      := '';
         V_DSITEMOCOR      := '';
         V_DSFLEGALOCOR    := '';
         V_CDAJUSTEITMAPA  := 'MG10000004';
         V_CDAJUSTEITSEF   := '';
         V_CDITPROCEDENCIA := '';

         V_BOANTECIP := FALSE;

         /******** Busca os dados das notas que j existiam, para recuperar as informaes alteradas pelo usurio ********/
         FOR I IN 1 .. V_CODANTECIPARROZ.COUNT LOOP
            IF (V_CODANTECIPARROZ(I).CDFILIAL   = C_ANTECIPARROZ.CDFILIAL)   AND
               (V_CODANTECIPARROZ(I).NRLANCTONF = C_ANTECIPARROZ.NRLANCTONF) THEN
               V_NRSEQITMAPR     := V_CODANTECIPARROZ(I).NRSEQITMAPR;
               V_CDITEMOCOR      := V_CODANTECIPARROZ(I).CDITEMOCOR;
               V_DSITEMOCOR      := V_CODANTECIPARROZ(I).DSITEMOCOR;
               V_DSFLEGALOCOR    := V_CODANTECIPARROZ(I).DSFLEGALOCOR;
               V_CDAJUSTEITMAPA  := V_CODANTECIPARROZ(I).CDAJUSTEITMAPA;
               V_CDAJUSTEITSEF   := V_CODANTECIPARROZ(I).CDAJUSTEITSEF;
               V_CDITPROCEDENCIA := V_CODANTECIPARROZ(I).CDITPROCEDENCIA;

               V_BOANTECIP := TRUE;
               EXIT;
            END IF;
         END LOOP;

         IF NOT V_BOANTECIP THEN
            V_NRSEQITMAPARECUP := NVL(V_NRSEQITMAPARECUP,0) + 1;
            V_NRSEQITMAPR := LPAD(V_NRSEQITMAPARECUP,10,'0');
         END IF;

         /******** Insere o item na ITMAPARECUP ********/
         INSERT INTO ITMAPARECUP
            (NRSEQUMAPAPU, IDTIPOITMAPR, NRSEQITMAPR, DSITEMMAPR, VRITEMMAPR, CDITEMOCOR, DSITEMOCOR,
             DSFLEGALOCOR, NRLANCTONF, CDFILIAL, CDAJUSTEITMAPA, CDAJUSTEITSEF, CDITPROCEDENCIA,
             IDCREDPRESUMIDO, IDDIFALMANUAL, IDCARGATRIBUTARIA, IDCOMPOEC197)
         VALUES
            (P_NRSEQUMAPAPU, 'OC', V_NRSEQITMAPR, 'ANTECIPAO ARROZ', C_ANTECIPARROZ.VRCONTABILNF, V_CDITEMOCOR,
             V_DSITEMOCOR, V_DSFLEGALOCOR, C_ANTECIPARROZ.NRLANCTONF, C_ANTECIPARROZ.CDFILIAL, V_CDAJUSTEITMAPA,
             V_CDAJUSTEITSEF, V_CDITPROCEDENCIA, 'N', 'S', 'N', 'D');
      END LOOP;
   END IF;
END;
/

-- VERSAO --
BEGIN ATUVEROBJ('ANTECIPACAO_ICMS_ARROZ','5.85.xxx'); END;
/



